import {
  injectProviders,
  rpcProviderWarning,
  selectProviders
} from "./chunk-LWRJTZY3.js";

// src/hooks/common/promptAndInjectEtherscan.ts
import fs from "fs-extra";
import { default as prompts } from "prompts";
import path from "path";
var promptAndInjectEtherscan = () => ({
  async afterValidate({ context }) {
    const errorMessage = "Etherscan API Key is required.";
    const etherscanApiKey = (await prompts({
      name: "etherscanApiKey",
      message: "What is your Etherscan API Key?",
      type: "text",
      validate(projectId) {
        if (!projectId)
          return errorMessage;
        return true;
      }
    })).etherscanApiKey;
    context.set({ etherscanApiKey });
  },
  async beforeInstall({ context, targetPath }) {
    const { etherscanApiKey } = context.get();
    if (!etherscanApiKey)
      return;
    if (!fs.existsSync(path.join(targetPath, ".env")))
      fs.writeFileSync(path.join(targetPath, ".env"), "");
    fs.appendFileSync(
      path.join(targetPath, ".env"),
      `ETHERSCAN_API_KEY=${etherscanApiKey}
`
    );
  }
});

// src/hooks/common/selectAndInjectProviders.ts
var selectAndInjectProviders = ({
  envNamespace,
  envPrefix
}) => ({
  async afterValidate({ context }) {
    const { envVars, providerNames } = await selectProviders();
    context.set({ envVars, providerNames });
  },
  async beforeInstall({ context, targetPath }) {
    const { envVars, providerNames } = context.get();
    injectProviders({
      envNamespace,
      envPrefix,
      envVars,
      providerNames,
      targetPath
    });
  },
  async afterSetup({ context }) {
    const { providerNames } = context.get();
    if (providerNames.length === 1 && providerNames[0] === "public") {
      rpcProviderWarning();
    }
  }
});

export {
  promptAndInjectEtherscan,
  selectAndInjectProviders
};
