// src/hooks/web3modal/promptAndInjectProjectId.ts
import fs from "fs-extra";
import pico from "picocolors";
import { default as prompts } from "prompts";
import path from "path";
var log = console.log;
var promptAndInjectProjectId = () => ({
  async afterValidate({ context }) {
    const errorMessage = "Project ID is required.";
    const walletConnectProjectId = (await prompts({
      name: "walletConnectProjectId",
      message: `What is your WalletConnect Cloud Project ID?
${pico.blue(
        "Find it at: https://cloud.walletconnect.com/sign-in"
      )}
`,
      type: "text",
      validate(projectId) {
        if (!projectId)
          return errorMessage;
        return true;
      }
    })).walletConnectProjectId;
    if (!walletConnectProjectId)
      throw new Error(errorMessage);
    context.set({ walletConnectProjectId });
  },
  async afterInstall({ context, targetPath }) {
    const { walletConnectProjectId } = context.get();
    if (!walletConnectProjectId)
      return;
    const configPath = path.join(targetPath, "src", "wagmi.ts");
    const config = fs.readFileSync(configPath).toString();
    fs.writeFileSync(
      configPath,
      config.replace("<WALLET_CONNECT_PROJECT_ID>", walletConnectProjectId)
    );
    log(pico.green("\u2714"), "Added WalletConnect Project ID.");
    log();
  }
});

export {
  promptAndInjectProjectId
};
